/**
 * Copyrightc2012 NTT DATA CORPORATION
 */

package com.sample;

import java.io.*;

public class HulftSend {
	/**
	 * 配信管理情報の登録
	 */
	public static final String[] pre_env = { "HULEXEP=/usr/local/HULFT/bin","PATH=/usr/local/HULFT/bin:$PATH",
												"HULPATH=/usr/local/HULFT/etc" };//HULFTの環境変数
	
	public static void main(String[] args) {
		String os = osCheck();//実行環境のOSをチェック
		makeFile(os, args[0], args[1], args[2]);//配信管理情報のパラメータファイルを作成
		addSendInfo(os);//配信管理情報の登録
	}

	//実行環境のOSをチェック
	public static String osCheck() {
		String osname = System.getProperty("os.name");
		return osname;
	}

	//配信管理情報のパラメータファイルを作成
	public static void makeFile(String os, String fileid, String filename, String groupid) {
		FileWriter fw = null;
		try {
			String newline = "";//改行
			if (os.indexOf("Windows") != -1) {//Windowsの場合
				newline = "\r\n";
			} else {//Linuxの場合
				newline = "\n";
			}
    		String [] snd = {"SNDFILE="+fileid, "FILENAME="+filename, "INTERVAL=0", "BLOCKLEN=4096", "BLOCKCNT=3",
    								"COMP=NO", "COMPSIZE=0", "TRANSPRTY=50", "TRANSTYPE=TEXT", "CODESET=A", "KJCHNGE=S",
    								"SHIFTTRANSACT=Y", "CLEAR=K", "GRPID="+groupid, "END"};//配信管理情報のパラメータ
			File fl = new File("./hulftsnd.txt");//パラメータファイル
			fl.createNewFile();//ファイルが存在しない場合、ファイルを生成
			fw = new FileWriter(fl);
			for (int i = 0; i < snd.length; i++) {//ファイルにパラメータを書き込む
				fw.write(snd[i] + newline);//各項目のパラメータ＋改行
			}
		} catch (IOException e) {
			System.out.println(e.getMessage());
			e.printStackTrace();
		} finally {
			try{
				fw.close();
			} catch (IOException e) {
				System.out.println(e.getMessage());
				e.printStackTrace();
			}
		}
	}

	// 配信管理情報の登録
	public static void addSendInfo(String os) {
		try {
			String command = "";//実行コマンド
			if (os.indexOf("Windows") != -1) {
				command = "\"C:\\HULFT Family\\hulft7\\binnt\\utliupdt.exe\" -f ./hulftsnd.txt -r";//配信管理情報登録コマンド
				Runtime rt = Runtime.getRuntime();
				Process process = rt.exec(command);//コマンドの実行
				checkError(process);//コマンドの実行結果をチェック
			} else {
				String[] env = pre_env;//HULFTの環境変数
				command = "/usr/local/HULFT/bin/utliupdt -f ./hulftsnd.txt -r";//配信管理情報登録コマンド
				Runtime rt = Runtime.getRuntime();
				Process process = rt.exec(command, env);//コマンドの実行
				checkError(process);//コマンドの実行結果をチェック
			}
			System.out.println("配信管理情報の登録が完了しました。");
		} catch (IOException e) {
			System.out.println(e.getMessage());
			e.printStackTrace();
		}
	}

	// 標準エラー出力と戻り値を表示
	public static void checkError(Process process) {
		InputStream stream = null;
		BufferedReader br = null;
		try {
			int ret = process.waitFor();//コマンドの戻り値
			stream = process.getInputStream();
			br = new BufferedReader(new InputStreamReader(stream));
			if (ret != 0) {//コマンドの戻り値が0でない場合
				String line;
				while ((line = br.readLine()) != null) {//標準エラーがある限り読み込む
					System.out.println(line);//標準エラーの出力
				}
				System.out.println("戻り値：" + ret);//戻り値の出力
				System.out.println("配信管理情報の登録に失敗しました。");
				System.exit(2);//リターンコード「2」で終了
			}
		} catch (IOException e) {
			System.out.println(e.getMessage());
			e.printStackTrace();
		} catch (InterruptedException e) {
			System.out.println(e.getMessage());
			e.printStackTrace();
		} finally {
			try{
				stream.close();
				br.close();
			} catch (IOException e) {
				System.out.println(e.getMessage());
				e.printStackTrace();
			}
		}
	}
}
